@@ -5,15 +5,15 @@ from __future__ import annotations
 import os
 import sys
 from contextlib import contextmanager
-from functools import partial
+from functools import partial, wraps
 from importlib.metadata import version as pkgversion
 from pathlib import Path
-from typing import TYPE_CHECKING
+from typing import TYPE_CHECKING, Any
 
 from duty import duty, tools
 
 if TYPE_CHECKING:
-    from collections.abc import Iterator
+    from collections.abc import Callable, Iterator
 
     from duty.context import Context
 
@@ -34,6 +34,21 @@ def pyprefix(title: str) -> str:  # noqa: D103
     return title
 
 
+def not_from_insiders(func: Callable) -> Callable:  # noqa: D103
+    @wraps(func)
+    def wrapper(ctx: Context, *args: Any, **kwargs: Any) -> None:
+        origin = ctx.run("git config --get remote.origin.url", silent=True)
+        if "pawamoy-insiders/griffe" in origin:
+            ctx.run(
+                lambda: False,
+                title="Not running this task from insiders repository (do that from public repo instead!)",
+            )
+            return
+        func(ctx, *args, **kwargs)
+
+    return wrapper
+
+
 @contextmanager
 def material_insiders() -> Iterator[bool]:  # noqa: D103
     if "+insiders" in pkgversion("mkdocs-material"):
@@ -297,7 +312,7 @@ def docs(ctx: Context, *cli_args: str, host: str = "127.0.0.1", port: int = 8000
 
 
 @duty
-def docs_deploy(ctx: Context) -> None:
+def docs_deploy(ctx: Context, *, force: bool = False) -> None:
     """Deploy the documentation to GitHub pages.
 
     ```bash
@@ -305,6 +320,9 @@ def docs_deploy(ctx: Context) -> None:
     ```
 
     Use [MkDocs](https://www.mkdocs.org/) to build and deploy the documentation to GitHub pages.
+
+    Parameters:
+        force: Whether to force deployment, even from non-Insiders version.
     """
     os.environ["DEPLOY"] = "true"
     with material_insiders() as insiders:
@@ -322,6 +340,11 @@ def docs_deploy(ctx: Context) -> None:
                 tools.mkdocs.gh_deploy(remote_name="upstream", force=True),
                 title="Deploying documentation",
             )
+        elif force:
+            ctx.run(
+                tools.mkdocs.gh_deploy(force=True),
+                title="Deploying documentation",
+            )
         else:
             ctx.run(
                 lambda: False,
@@ -369,6 +392,7 @@ def build(ctx: Context) -> None:
 
 
 @duty
+@not_from_insiders
 def publish(ctx: Context) -> None:
     """Publish source and wheel distributions to PyPI.
 
@@ -390,6 +414,7 @@ def publish(ctx: Context) -> None:
 
 
 @duty(post=["build", "publish", "docs-deploy"])
+@not_from_insiders
 def release(ctx: Context, version: str = "") -> None:
     """Release a new version of the project.
 
@@ -410,12 +435,6 @@ def release(ctx: Context, version: str = "") -> None:
     Parameters:
         version: The new version number to use. If not provided, you will be prompted for it.
     """
-    origin = ctx.run("git config --get remote.origin.url", silent=True)
-    if "pawamoy-insiders/griffe" in origin:
-        ctx.run(
-            lambda: False,
-            title="Not releasing from insiders repository (do that from public repo instead!)",
-        )
     if not (version := (version or input("> Version to release: ")).strip()):
         ctx.run("false", title="A version must be provided")
     ctx.run("git add pyproject.toml CHANGELOG.md", title="Staging files", pty=PTY)
