@@ -9,7 +9,7 @@ import pytest
 from griffe import ModulesCollection, temporary_inspected_module, temporary_visited_module
 
 if TYPE_CHECKING:
-    from griffe.dataclasses import Class
+    from griffe import Class
 
 
 def _mro_paths(cls: Class) -> list[str]:
